"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.emitTest = emitTest;
exports.emitSuite = emitSuite;
exports.default = exports.opts = exports.displayName = void 0;

var _sideUtils = require("@seleniumhq/side-utils");

var _command = _interopRequireDefault(require("./command"));

var _location = _interopRequireDefault(require("./location"));

var _hook = require("./hook");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

// Define language options
const displayName = 'JavaScript Mocha';
exports.displayName = displayName;
let opts = {};
exports.opts = opts;
opts.emitter = _command.default;
opts.hooks = (0, _hook.generateHooks)();
opts.fileExtension = '.spec.js';
opts.commandPrefixPadding = '  ';
opts.terminatingKeyword = '})';
opts.commentPrefix = '//';
opts.generateMethodDeclaration = generateMethodDeclaration; // Create generators for dynamic string creation of primary entities (e.g., filename, methods, test, and suite)

function generateTestDeclaration(name) {
  return `it('${name}', async function() {`;
}

function generateMethodDeclaration(name) {
  return {
    body: `async function ${_sideUtils.codeExport.parsers.uncapitalize(_sideUtils.codeExport.parsers.sanitizeName(name))}() {`,
    terminatingKeyword: '}'
  };
}

function generateSuiteDeclaration(name) {
  return `describe('${name}', function() {`;
}

function generateFilename(name) {
  return `${_sideUtils.codeExport.parsers.uncapitalize(_sideUtils.codeExport.parsers.sanitizeName(name))}${opts.fileExtension}`;
} // Emit an individual test, wrapped in a suite (using the test name as the suite name)


async function emitTest({
  baseUrl,
  test,
  tests,
  project,
  enableOriginTracing,
  beforeEachOptions,
  enableDescriptionAsComment
}) {
  global.baseUrl = baseUrl;
  const testDeclaration = generateTestDeclaration(test.name);
  const result = await _sideUtils.codeExport.emit.test(test, tests, _objectSpread(_objectSpread({}, opts), {}, {
    testDeclaration,
    enableOriginTracing,
    enableDescriptionAsComment,
    project
  }));
  const suiteName = test.name;
  const suiteDeclaration = generateSuiteDeclaration(suiteName);

  const _suite = await _sideUtils.codeExport.emit.suite(result, tests, _objectSpread(_objectSpread({}, opts), {}, {
    suiteDeclaration,
    suiteName,
    project,
    beforeEachOptions
  }));

  return {
    filename: generateFilename(test.name),
    body: _sideUtils.codeExport.emit.orderedSuite(_suite)
  };
} // Emit a suite with all of its tests


async function emitSuite({
  baseUrl,
  suite,
  tests,
  project,
  enableOriginTracing,
  beforeEachOptions,
  enableDescriptionAsComment
}) {
  global.baseUrl = baseUrl;
  const result = await _sideUtils.codeExport.emit.testsFromSuite(tests, suite, opts, {
    enableOriginTracing,
    generateTestDeclaration,
    enableDescriptionAsComment,
    project
  });
  const suiteDeclaration = generateSuiteDeclaration(suite.name);

  const _suite = await _sideUtils.codeExport.emit.suite(result, tests, _objectSpread(_objectSpread({}, opts), {}, {
    suiteDeclaration,
    suite,
    project,
    beforeEachOptions
  }));

  return {
    filename: generateFilename(suite.name),
    body: _sideUtils.codeExport.emit.orderedSuite(_suite)
  };
}

var _default = {
  emit: {
    test: emitTest,
    suite: emitSuite,
    locator: _location.default.emit
  },
  register: {
    command: _command.default.register,
    variable: opts.hooks.declareVariables.register,
    dependency: opts.hooks.declareDependencies.register,
    beforeAll: opts.hooks.beforeAll.register,
    beforeEach: opts.hooks.beforeEach.register,
    afterEach: opts.hooks.afterEach.register,
    afterAll: opts.hooks.afterAll.register,
    inEachBegin: opts.hooks.inEachBegin.register,
    inEachEnd: opts.hooks.inEachEnd.register
  }
};
exports.default = _default;